Method: Zilla::IoK8sApiCoreV1HTTPHeader#initialize
- Defined in:
- lib/zilla/models/io_k8s_api_core_v1_http_header.rb
#initialize(attributes = {}) ⇒ IoK8sApiCoreV1HTTPHeader
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/zilla/models/io_k8s_api_core_v1_http_header.rb', line 53 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, 'The input argument (attributes) must be a hash in `Zilla::IoK8sApiCoreV1HTTPHeader` initialize method' end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Zilla::IoK8sApiCoreV1HTTPHeader`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end self.name = attributes[:name] if attributes.key?(:name) return unless attributes.key?(:value) self.value = attributes[:value] end |